function SPL=evotion_d31_tts_predict(loggeddata,Parameters)
%
% EVOTION TTS prediction demo Deliverable 3.1
%
% Main output SPL.ATS which is the predicted Assymptotic Threshold Shift (ATS)
% shift for the logged SPL for normal hearing.
%
% Authors:
% - Adam Dudarewicz <Adam.Dudarewicz@imp.lodz.pl>, NIOM
% - Malgorzata Pawlaczyk-Luszczynska <Malgorzata.Pawlaczyk@imp.lodz.pl>, NIOM
% - Mariola Sliwinska-Kowalska <Mariola.Sliwinska@imp.lodz.pl>, NIOM
% - Panagiotis Katrakazas, <pan.katrakazas@gmail.com>, ICCS
% - Niels Henrik Pontoppidan <npon@eriksholm.com>, OTC
%
% Acknowledgement
% Work funded by EU through grant agreement 727521 EVOTION
%
% loggeddata must follow the EVOTION hearing aid data format Matrix with 3
% elements, first column SPL for 0-1 kHz, second column SPL for 1-4 kHz,
% third column SPL for 4-10 kHz one sample per minute at ear level
% 
%
SPL.loggeddata=loggeddata;

%% Parameters
if(nargin<2||isempty(Parameters))
    SPL.Parameters.PTS16h=960; %16-hour daily activity [min] 'Parameters&Results'!A$4
    SPL.Parameters.CeelLeX=77; %Ceeling LEX,16h value [dB] 'Parameters&Results'!A$7
    SPL.Parameters.smallTTS=5; %the smalest TTS 'Parameters&Results'!A$11
    SPL.Parameters.Cnst=2; %constant value to [h] 'Parameters&Results'!A$14
    SPL.Parameters.CritLe=78; %constant value Critical level dBA 'Parameters&Results'!A$17 
end

%% Datalogger during event
% SPL dBA Mobile Application Interface noiseMonitoringMAOP  LA=10*log10(0.4494 x10.^(0-SPL/10)+1.3007x10.^(1-SPL/10)+ 0.8595x10.^(2-SPL/10)) [D2.2]
SPL.dBA=10*log10(0.4494*10.^(SPL.loggeddata(:,1)/10)+1.3007*10.^(SPL.loggeddata(:,2)/10)+ 0.8595*10.^(SPL.loggeddata(:,3)/10));

N=size(SPL.dBA);

% LEQ(t); Current equivalent  continuous  SPL dBA
% =10*LOG10((10^(0,1*AD2))*(AB3/(AB3+1))+(10^(0,1*AC3)/(AB3+1)))
SPL.LEQ=SPL.dBA;
for k=2:N;
    SPL.LEQ(k)= 10*log10( 10.^(SPL.LEQ(k-1)/10)*(k-1)/k + 10.^(SPL.LEQ(k)/10)/k);
end

%LEX,16h(t); Current  noise exposure level related to 16 hour of the daily activity [dBA]
%=AD2+10*LOG10((AB2+1)/'Parameters&Results'!A$4)
SPL.LEQ16h=SPL.LEQ+10*log10((1:N)'/SPL.Parameters.PTS16h);

%Tc(t); time necessary to achive the smalest TTS  with current LEQ(t) [min]
% =(IF('Parameters&Results'!A$11<1,7*10*LOG10((10^(AD2/10))/(10^('Parameters&Results'!A$17/10))+1);'Parameters&Results'!A$14*LN(1/(1-('Parameters&Results'!A$11/(1,7*10*LOG10((10^(AD2/10))/(10^('Parameters&Results'!A$17/10))+1)))));1000))*60
% 'Parameters&Results'!A$11 is SPL.Parameters.smallTTS;
% 'Parameters&Results'!A$14 is SPL.Parameters.Cnst
% 'Parameters&Results'!A$17 is SPL.Parameters.CritLe;
% AD2 is SPL.LEQ16h
% =(IF(Parameters.smallTTS<1,7*10*LOG10((10^(AD2/10))/(10^(Parameters.CritLe/10))+1);Parameters.Cnst*LN(1/(1-(Parameters.smallTTS/(1,7*10*LOG10((10^(AD2/10))/(10^(Parameters.CritLe/10))+1)))));1000))*60

SPL.tts.testcmp=1.7*10*log10((10.^(SPL.LEQ16h/10))/(10^(SPL.Parameters.CritLe/10))+1);
SPL.tts.testflag=SPL.Parameters.smallTTS<SPL.tts.testcmp;


SPL.TC=60*SPL.Parameters.Cnst*log(1/(1-(SPL.Parameters.smallTTS./SPL.tts.testcmp)));
SPL.TC(SPL.tts.testflag==0)=60000;

SPL.ATS=max(1.7*10*log10( (4e-10*10.^(SPL.LEQ16h/10)+4e-10*10.^(SPL.Parameters.CritLe/10))/(4e-10*10.^(SPL.Parameters.CritLe/10))));


