function TTS=evotion_d31_tts_predict_demo_bd;
%
% EVOTION TTS prediction demo Deliverable 3.1
% 
% This function uses a set of logged data from a concert venue to simulate
% the TTS encountered for a range of hearing losses and for positions which
% are either in half and double distance from loudspeakers than the
% position where the sound pressure data was logged
%
% 
% Authors:
% - Adam Dudarewicz <Adam.Dudarewicz@imp.lodz.pl>, NIOM
% - Malgorzata Pawlaczyk-Luszczynska <Malgorzata.Pawlaczyk@imp.lodz.pl>, NIOM
% - Mariola Sliwinska-Kowalska <Mariola.Sliwinska@imp.lodz.pl>, NIOM
% - Panagiotis Katrakazas, <pan.katrakazas@gmail.com>, ICCS
% - Niels Henrik Pontoppidan <npon@eriksholm.com>, OTC
%
% Acknowledgement
% Work funded by EU through grant agreement 727521 EVOTION
%

evotion_d31_testdata; %creates the testdata structure with SPL in three bands

DIST=[.25 0.5 1 2];
fid=fopen('data.csv','r'); %file with audiograms
%Any file that follows this format up to column 9 (L8k) may be used
%test_date,nid,L500k,L1k,L2k,L3k,L4k,L6k,L8k,R500k,R1k,R2k,R3k,R4k,R6k,R8k,gender,naics,age_group,region,NAICS_descr
%         1   2     3   4   5   6   7   8   9

%
NumberOfAudiograms=1048576;
LFHL(NumberOfAudiograms,1)=0;
MFHL=LFHL; 
HFHL=LFHL;
FTAV=HFHL;
TTS=repmat(HFHL,1,numel(DIST));

tline=fgetl(fid); % get rid of headers
idx=[2 3 4 5 6 7 8];
N=0;
while 1
    tline=fgetl(fid);
    if(~ischar(tline)), break, end
%     if(N>50000), LFHL(N+1:end)=[]; MFHL(N+1:end)=[]; HFHL(N+1:end)=[]; FTAV(N+1:end)=[]; TTS(N+1:end,:)=[]; break, end
    N=N+1;
    pos=find(tline==',');
    for k=1:length(idx),
            aud(k)=str2num(['0' tline(pos(idx(k))+1:pos(idx(k)+1)-1)]);
    end
    aud(aud>100)=100;
    LFHL(N)=max(0,mean(aud(1:2)));
    MFHL(N)=max(0,mean(aud(4:6)));
    HFHL(N)=max(0,mean(aud(6:end)));
    FTAV(N)=mean(aud([2 3 4 6]));
    for kdist=1:length(DIST),
        SPL=evotion_d31_tts_predict( evotion_d31_genericgain(testdata-20*log10(DIST(kdist)),[LFHL(N) MFHL(N) HFHL(N)]));
        TTS(N,kdist)=evotion_d31_tts_predict_HL(SPL.ATS,FTAV(N));
    end
end
fclose(fid);
H=char('Front row','Front group','Middle group','Rear group','Smallest predictable TTS');
K=randperm(length(FTAV));
STP=floor(length(K)/4);
idx1=K(1:STP);idx2=K(STP+1:2*STP);idx3=K(2*STP+1:3*STP);idx4=K(3*STP+1:4*STP);
save('evotion_d31_data.mat');

%%

figure(1); 
plot(FTAV(idx4),TTS(idx4,4),'p',FTAV(idx3),TTS(idx3,3),'o',FTAV(idx2),TTS(idx2,2),'s',FTAV(idx1),TTS(idx1,1),'x',[min(FTAV) max(FTAV)],SPL.Parameters.smallTTS*[1 1],'k--');
legend(H([4 3 2 1 5],:));
xlim([min(FTAV) max(FTAV)]);
H2=get(gca,'Children');
xlabel({'Hearing loss [dB]','Four tone frequency average (0.5, 1, 2, and 4 kHz)'})
ylabel('Predicted Temporary Threshold Shift [dB]');
title('Simulated Temporary Threshold Shifts (TTS) at concert for large group');

figure(2); 
[bins,cnts]=hist([TTS(idx4,4) TTS(idx3,3) TTS(idx2,2) TTS(idx1,1)],-2.5:5:37.5);
bar(cnts,bins/length(idx4)*100);
hold on
plot([5 5],ylim,'k--')
hold off
H3=get(gca,'Children');
xlabel('Predicted Temporary Threshold Shift [dB]');
ylabel('Occurence in population [%]');
title('Simulated Temporary Threshold Shifts (TTS) at concert for large group');
legend(H([4 3 2 1 5],:))
xlim([0 40]);
for k=2:5, set(H3(k),'FaceColor',get(H2(k),'Color')); end
%%
saveas(1,'TTSPLOT.fig');
saveas(2,'TTSHIST.fig');
